==> netxms-3.9.280.tar.gz: netxms-3.9.280/include/base64.h <==
/* base64.h -- Encode binary data using printable characters.
   Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
   Written by Simon Josefsson.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */

#ifndef BASE64_H
#define BASE64_H

/* Get size_t. */
#include <stddef.h>

/* This uses that the expression (n+(k-1))/k means the smallest
   integer >= n/k, i.e., the ceiling of n/k.  */
#define BASE64_LENGTH(inlen) ((((inlen) + 2) / 3) * 4)

BOOL LIBNETXMS_EXPORTABLE isbase64 (char ch);

void LIBNETXMS_EXPORTABLE base64_encode (const char *in, size_t inlen,
			   char *out, size_t outlen);

size_t LIBNETXMS_EXPORTABLE base64_encode_alloc (const char *in, size_t inlen, char **out);

BOOL LIBNETXMS_EXPORTABLE base64_decode (const char *in, size_t inlen,
			   char *out, size_t *outlen);

BOOL LIBNETXMS_EXPORTABLE base64_decode_alloc (const char *in, size_t inlen,
				 char **out, size_t *outlen);

#endif /* BASE64_H */

==> netxms-4.1.420.tar.gz: netxms-4.1.420/include/base64.h <==
/* base64.h -- Encode binary data using printable characters.
   Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
   Written by Simon Josefsson.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */

#ifndef BASE64_H
#define BASE64_H

/* Get size_t. */
#include <stddef.h>

/* This uses that the expression (n+(k-1))/k means the smallest
   integer >= n/k, i.e., the ceiling of n/k.  */
#define BASE64_LENGTH(inlen) ((((inlen) + 2) / 3) * 4)

bool LIBNETXMS_EXPORTABLE isbase64(char ch);

void LIBNETXMS_EXPORTABLE base64_encode(const char *in, size_t inlen, char *out, size_t outlen);

size_t LIBNETXMS_EXPORTABLE base64_encode_alloc(const char *in, size_t inlen, char **out);

bool LIBNETXMS_EXPORTABLE base64_decode(const char *in, size_t inlen, char *out, size_t *outlen);

bool LIBNETXMS_EXPORTABLE base64_decode_alloc(const char *in, size_t inlen, char **out, size_t *outlen);

#endif /* BASE64_H */
